@@ -7,5 +7,8 @@ pub use sqlx::{self, Row as SqlxRow};
 #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
 pub use sqlx::any;
 pub use async_trait;
+pub use regex;
 pub use anyhow;
+pub use chrono;
+pub use serde;
 pub use serde_json::{self, Value as Json, json};
\ No newline at end of file
