@@ -31,7 +31,13 @@ pub trait ArelAble: Sized + Send + Sync {
 
     fn id() -> &'static str { Self::primary_key() }
     fn primary_key() -> &'static str { "id" }
-    fn locking_column() -> &'static str { "lock_version" }
+    fn locking_column() -> Option<&'static str> { None }
+    fn get_persisted_locking_column_attr_value(&self) -> anyhow::Result<Option<i32>> {
+        Err(anyhow::anyhow!("locking_version not support"))
+    }
+    fn set_locking_column_attr_value(&mut self, _locking_version: i32) -> anyhow::Result<()> {
+        Err(anyhow::anyhow!("locking_version not support"))
+    }
     fn table_name() -> String {
         Table::<Self>::table_name()
     }
@@ -163,8 +169,7 @@ pub trait ArelAble: Sized + Send + Sync {
     }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn with_lock<F: Send>(&self, callback: F) -> anyhow::Result<Option<Self>>
-        where for<'c>
-              F: FnOnce(&'c mut sqlx::Transaction<sqlx::Any>) -> Pin<Box<dyn Future<Output = anyhow::Result<Option<Self>>> + Send + 'c >>
+        where for<'c> F: FnOnce(&'c mut sqlx::Transaction<sqlx::Any>) -> Pin<Box<dyn Future<Output = anyhow::Result<Option<Self>>> + Send + 'c >>
     {
         let mut tx = Self::transaction_start().await?;
         if let Err(e) = self.lock_self_with_executor(&mut tx).await {
