@@ -1,18 +1,17 @@
-use arel::prelude::*;
-use chrono::prelude::*;
-
-#[arel]
-struct User {
-    id: i64,
-}
-
-#[allow(dead_code)]
+#[cfg(feature = "mysql")]
 #[cfg(test)]
 mod query {
-    use super::*;
+    use arel::prelude::*;
+    use chrono::prelude::*;
+
+    #[arel]
+    struct User {
+        id: i64,
+    }
+
     #[test]
     fn test_select() {
-        let sql = User::query().to_sql_string().unwrap();
+        let sql: String = User::query().into();
         assert_eq!(sql, "SELECT `users`.* FROM `users`");
         let sql = User::query().distinct().to_sql_string().unwrap();
         assert_eq!(sql, "SELECT DISTINCT `users`.* FROM `users`");
